==> switchyard-component-http-0.6.0.Final-sources.jar: org/switchyard/component/http/selector/HttpOperationSelectorFactory.java <==
/*
 * JBoss, Home of Professional Open Source Copyright 2009, Red Hat Middleware
 * LLC, and individual contributors by the @authors tag. See the copyright.txt
 * in the distribution for a full listing of individual contributors.
 * 
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA, or see the FSF
 * site: http://www.fsf.org.
 */
package org.switchyard.component.http.selector;

import org.switchyard.component.common.selector.OperationSelector;
import org.switchyard.component.common.selector.OperationSelectorFactory;
import org.switchyard.component.http.composer.HttpBindingData;

/**
 * OperationSelectorFactory implementation for HTTP binding.
 */
public class HttpOperationSelectorFactory extends OperationSelectorFactory<HttpBindingData> {

    @Override
    public Class<HttpBindingData> getTargetClass() {
        return HttpBindingData.class;
    }

    @Override
    public Class<? extends OperationSelector<HttpBindingData>> getDefaultOperationSelectorClass() {
        return HttpOperationSelector.class;
    }

}

==> switchyard-component-http-0.8.0.Final-sources.jar: org/switchyard/component/http/selector/HttpOperationSelectorFactory.java <==
/*
 * JBoss, Home of Professional Open Source Copyright 2009, Red Hat Middleware
 * LLC, and individual contributors by the @authors tag. See the copyright.txt
 * in the distribution for a full listing of individual contributors.
 * 
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA, or see the FSF
 * site: http://www.fsf.org.
 */
package org.switchyard.component.http.selector;

import org.switchyard.component.common.selector.OperationSelectorFactory;
import org.switchyard.component.http.composer.HttpBindingData;
import org.switchyard.selector.OperationSelector;

/**
 * OperationSelectorFactory implementation for HTTP binding.
 */
public class HttpOperationSelectorFactory extends OperationSelectorFactory<HttpBindingData> {

    @Override
    public Class<HttpBindingData> getTargetClass() {
        return HttpBindingData.class;
    }

    @Override
    public Class<? extends OperationSelector<HttpBindingData>> getDefaultOperationSelectorClass() {
        return HttpOperationSelector.class;
    }

}
